@@ -8,7 +8,7 @@ use std::rc::Rc;
 
 use anyhow::{anyhow, bail, Context as _, Result};
 use serde::{Deserialize, Serialize};
-use serde_yaml::Value;
+use serde_yaml::{Mapping, Value};
 use wildmatch::WildMatch;
 
 use crate::ioutil;
@@ -28,13 +28,13 @@ pub struct KubeConfig {
 #[derive(Clone, Debug, Deserialize, Serialize)]
 pub struct NamedCluster {
     pub name: String,
-    pub cluster: Value,
+    pub cluster: Mapping,
 }
 
 #[derive(Clone, Debug, Deserialize, Serialize)]
 pub struct NamedUser {
     pub name: String,
-    pub user: Value,
+    pub user: Mapping,
 }
 
 #[derive(Clone, Debug, Deserialize, Serialize)]
@@ -157,6 +157,17 @@ impl Installed {
         Ok(())
     }
 
+    fn make_path_absolute(mapping: &mut Mapping, key: &str, parent: &Path) {
+        if !mapping.contains_key(key) {
+            return;
+        }
+        let str = mapping.get(key).unwrap().as_str().expect("value should be a string");
+        let path = Path::new(str);
+        if !path.is_absolute() {
+            mapping.insert(key.into(), parent.join(path).to_str().expect("path should be a valid unicode string").into());
+        }
+    }
+
     pub fn make_kubeconfig_for_context(
         &self,
         context_name: &str,
@@ -170,8 +181,9 @@ impl Installed {
             .ok_or_else(|| anyhow!("Could not find context {}", context_name))?;
 
         context_src.item.context.namespace = namespace_name.map(Into::into);
+        let kubeconfig_dir = context_src.source.parent().expect("kubeconfig path should have a parent dir");
 
-        let cluster = self
+        let cluster_src = self
             .find_cluster_by_name(&context_src.item.context.cluster, &context_src.source)
             .cloned()
             .ok_or_else(|| {
@@ -182,7 +194,11 @@ impl Installed {
                 )
             })?;
 
-        let user = self
+        let mut named_cluster = cluster_src.item;
+        let cluster = &mut named_cluster.cluster;
+        Self::make_path_absolute(cluster, "certificate-authority", kubeconfig_dir);
+
+        let user_src = self
             .find_user_by_name(&context_src.item.context.user, &context_src.source)
             .cloned()
             .ok_or_else(|| {
@@ -193,10 +209,16 @@ impl Installed {
                 )
             })?;
 
+        let mut named_user = user_src.item;
+        let user = &mut named_user.user;
+
+        Self::make_path_absolute(user, "client-certificate", kubeconfig_dir);
+        Self::make_path_absolute(user, "client-key", kubeconfig_dir);
+
         Ok(KubeConfig {
-            clusters: vec![cluster.item],
+            clusters: vec![named_cluster],
             contexts: vec![context_src.item],
-            users: vec![user.item],
+            users: vec![named_user],
             current_context: Some(context_name.into()),
             others: {
                 let mut m: HashMap<String, Value> = HashMap::new();
