@@ -14,6 +14,7 @@ use crate::vars;
 mod bash;
 mod detect;
 mod fish;
+mod nu;
 mod prompt;
 mod xonsh;
 mod zsh;
@@ -108,6 +109,9 @@ pub fn spawn_shell(settings: &Settings, config: KubeConfig, session: &Session) -
         ShellKind::Zsh => {
             env_vars.insert("KUBIE_SHELL", "zsh");
         }
+        ShellKind::Nu => {
+            env_vars.insert("KUBIE_SHELL", "nu");
+        }
     }
 
     let info = ShellSpawnInfo {
@@ -121,5 +125,6 @@ pub fn spawn_shell(settings: &Settings, config: KubeConfig, session: &Session) -
         ShellKind::Fish => fish::spawn_shell(&info),
         ShellKind::Xonsh => xonsh::spawn_shell(&info),
         ShellKind::Zsh => zsh::spawn_shell(&info),
+        ShellKind::Nu => nu::spawn_shell(&info),
     }
 }
